# M3LD Sandbox

### Getting Started

In order to get started quickly with M3LD Sandbox, a sample project is bundled within the M3LD Sandbox CLI that will set up a server, privacy center, and a sample application for you to experiment with.

#### Minimum requirements

- [Docker](https://www.docker.com/products/docker-desktop) (version 20.10.11 or later)
- [Python](https://www.python.org/downloads/) (version 3.8 through 3.10)

#### Download and install M3LD Sandbox

You can easily download and install M3LD Sandbox using `pip`. Run the following command to get started:

```sh
pip install meld-sandbox
```
